( cd usr/lib ; rm -rf libbraille.so )
( cd usr/lib ; ln -sf libbraille-0.so.14.3.1 libbraille.so )
( cd usr/lib/libbraille ; rm -rf fake.so )
( cd usr/lib/libbraille ; ln -sf fake-0.so.14.3.1 fake.so )
( cd usr/lib/libbraille ; rm -rf text-0.so.14 )
( cd usr/lib/libbraille ; ln -sf text-0.so.14.3.1 text-0.so.14 )
( cd usr/lib/libbraille ; rm -rf papenmeierusb.so )
( cd usr/lib/libbraille ; ln -sf papenmeierusb-0.so.14.3.1 papenmeierusb.so )
( cd usr/lib/libbraille ; rm -rf eurobraille.so )
( cd usr/lib/libbraille ; ln -sf eurobraille-0.so.14.3.1 eurobraille.so )
( cd usr/lib/libbraille ; rm -rf braillelite.so )
( cd usr/lib/libbraille ; ln -sf braillelite-0.so.14.3.1 braillelite.so )
( cd usr/lib/libbraille ; rm -rf technibraille.so )
( cd usr/lib/libbraille ; ln -sf technibraille-0.so.14.3.1 technibraille.so )
( cd usr/lib/libbraille ; rm -rf baum-0.so.14 )
( cd usr/lib/libbraille ; ln -sf baum-0.so.14.3.1 baum-0.so.14 )
( cd usr/lib/libbraille ; rm -rf technibraille-0.so.14 )
( cd usr/lib/libbraille ; ln -sf technibraille-0.so.14.3.1 technibraille-0.so.14 )
( cd usr/lib/libbraille ; rm -rf fake-0.so.14 )
( cd usr/lib/libbraille ; ln -sf fake-0.so.14.3.1 fake-0.so.14 )
( cd usr/lib/libbraille ; rm -rf voyager-0.so.14 )
( cd usr/lib/libbraille ; ln -sf voyager-0.so.14.3.1 voyager-0.so.14 )
( cd usr/lib/libbraille ; rm -rf text.so )
( cd usr/lib/libbraille ; ln -sf text-0.so.14.3.1 text.so )
( cd usr/lib/libbraille ; rm -rf handytech-0.so.14 )
( cd usr/lib/libbraille ; ln -sf handytech-0.so.14.3.1 handytech-0.so.14 )
( cd usr/lib/libbraille ; rm -rf papenmeierusb-0.so.14 )
( cd usr/lib/libbraille ; ln -sf papenmeierusb-0.so.14.3.1 papenmeierusb-0.so.14 )
( cd usr/lib/libbraille ; rm -rf alva.so )
( cd usr/lib/libbraille ; ln -sf alva-0.so.14.3.1 alva.so )
( cd usr/lib/libbraille ; rm -rf eurobraille-0.so.14 )
( cd usr/lib/libbraille ; ln -sf eurobraille-0.so.14.3.1 eurobraille-0.so.14 )
( cd usr/lib/libbraille ; rm -rf once-0.so.14 )
( cd usr/lib/libbraille ; ln -sf once-0.so.14.3.1 once-0.so.14 )
( cd usr/lib/libbraille ; rm -rf braillelite-0.so.14 )
( cd usr/lib/libbraille ; ln -sf braillelite-0.so.14.3.1 braillelite-0.so.14 )
( cd usr/lib/libbraille ; rm -rf voyager.so )
( cd usr/lib/libbraille ; ln -sf voyager-0.so.14.3.1 voyager.so )
( cd usr/lib/libbraille ; rm -rf once.so )
( cd usr/lib/libbraille ; ln -sf once-0.so.14.3.1 once.so )
( cd usr/lib/libbraille ; rm -rf none.so )
( cd usr/lib/libbraille ; ln -sf none-0.so.14.3.1 none.so )
( cd usr/lib/libbraille ; rm -rf braillenote-0.so.14 )
( cd usr/lib/libbraille ; ln -sf braillenote-0.so.14.3.1 braillenote-0.so.14 )
( cd usr/lib/libbraille ; rm -rf braillenote.so )
( cd usr/lib/libbraille ; ln -sf braillenote-0.so.14.3.1 braillenote.so )
( cd usr/lib/libbraille ; rm -rf none-0.so.14 )
( cd usr/lib/libbraille ; ln -sf none-0.so.14.3.1 none-0.so.14 )
( cd usr/lib/libbraille ; rm -rf alva-0.so.14 )
( cd usr/lib/libbraille ; ln -sf alva-0.so.14.3.1 alva-0.so.14 )
( cd usr/lib/libbraille ; rm -rf alvausb-0.so.14 )
( cd usr/lib/libbraille ; ln -sf alvausb-0.so.14.3.1 alvausb-0.so.14 )
( cd usr/lib/libbraille ; rm -rf baum.so )
( cd usr/lib/libbraille ; ln -sf baum-0.so.14.3.1 baum.so )
( cd usr/lib/libbraille ; rm -rf alvausb.so )
( cd usr/lib/libbraille ; ln -sf alvausb-0.so.14.3.1 alvausb.so )
( cd usr/lib/libbraille ; rm -rf handytech.so )
( cd usr/lib/libbraille ; ln -sf handytech-0.so.14.3.1 handytech.so )
( cd usr/lib ; rm -rf libbraille-0.so.14 )
( cd usr/lib ; ln -sf libbraille-0.so.14.3.1 libbraille-0.so.14 )
( cd usr/lib/python2.5/site-packages ; rm -rf _braille.so.0 )
( cd usr/lib/python2.5/site-packages ; ln -sf _braille.so.0.0.0 _braille.so.0 )
( cd usr/lib/python2.5/site-packages ; rm -rf _braille.so )
( cd usr/lib/python2.5/site-packages ; ln -sf _braille.so.0.0.0 _braille.so )
