# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.38
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.
# This file is compatible with both classic and new-style classes.

from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        try:
            fp, pathname, description = imp.find_module('_braille', [dirname(__file__)])
            _mod = imp.load_module('_braille', fp, pathname, description)
        finally:
            if fp is not None: fp.close()
        return _mod
    _braille = swig_import_helper()
    del swig_import_helper
else:
    import _braille
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


BRL_NONE = _braille.BRL_NONE
BRL_KEY = _braille.BRL_KEY
BRL_CURSOR = _braille.BRL_CURSOR
BRL_CMD = _braille.BRL_CMD
BRL_ACC = _braille.BRL_ACC
class brl_key(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, brl_key, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, brl_key, name)
    __repr__ = _swig_repr
    __swig_setmethods__["type"] = _braille.brl_key_type_set
    __swig_getmethods__["type"] = _braille.brl_key_type_get
    if _newclass:type = _swig_property(_braille.brl_key_type_get, _braille.brl_key_type_set)
    __swig_setmethods__["braille"] = _braille.brl_key_braille_set
    __swig_getmethods__["braille"] = _braille.brl_key_braille_get
    if _newclass:braille = _swig_property(_braille.brl_key_braille_get, _braille.brl_key_braille_set)
    __swig_setmethods__["code"] = _braille.brl_key_code_set
    __swig_getmethods__["code"] = _braille.brl_key_code_get
    if _newclass:code = _swig_property(_braille.brl_key_code_get, _braille.brl_key_code_set)
    __swig_setmethods__["unicode"] = _braille.brl_key_unicode_set
    __swig_getmethods__["unicode"] = _braille.brl_key_unicode_get
    if _newclass:unicode = _swig_property(_braille.brl_key_unicode_get, _braille.brl_key_unicode_set)
    def __init__(self): 
        this = _braille.new_brl_key()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _braille.delete_brl_key
    __del__ = lambda self : None;
brl_key_swigregister = _braille.brl_key_swigregister
brl_key_swigregister(brl_key)

BRL_DEVICE = _braille.BRL_DEVICE
BRL_DRIVER = _braille.BRL_DRIVER
BRL_TERMINAL = _braille.BRL_TERMINAL
BRL_TABLE = _braille.BRL_TABLE
BRL_PATH = _braille.BRL_PATH
BRL_VERSION = _braille.BRL_VERSION
BRL_PATHDRV = _braille.BRL_PATHDRV
BRL_PATHTBL = _braille.BRL_PATHTBL
BRL_PATHCONF = _braille.BRL_PATHCONF
BRL_TYPE_UNKNOWN = _braille.BRL_TYPE_UNKNOWN
BRL_TYPE_SPECIAL = _braille.BRL_TYPE_SPECIAL
BRL_TYPE_SERIAL = _braille.BRL_TYPE_SERIAL
BRL_TYPE_USB = _braille.BRL_TYPE_USB

def braille_config(*args):
  return _braille.braille_config(*args)
braille_config = _braille.braille_config

def braille_drivernum():
  return _braille.braille_drivernum()
braille_drivernum = _braille.braille_drivernum

def braille_drivername(*args):
  return _braille.braille_drivername(*args)
braille_drivername = _braille.braille_drivername

def braille_drivertype(*args):
  return _braille.braille_drivertype(*args)
braille_drivertype = _braille.braille_drivertype

def braille_drivermodels(*args):
  return _braille.braille_drivermodels(*args)
braille_drivermodels = _braille.braille_drivermodels

def braille_driverauto(*args):
  return _braille.braille_driverauto(*args)
braille_driverauto = _braille.braille_driverauto

def braille_driver_is_type(*args):
  return _braille.braille_driver_is_type(*args)
braille_driver_is_type = _braille.braille_driver_is_type

def braille_tablenum():
  return _braille.braille_tablenum()
braille_tablenum = _braille.braille_tablenum

def braille_tablename(*args):
  return _braille.braille_tablename(*args)
braille_tablename = _braille.braille_tablename

def braille_tabledesc(*args):
  return _braille.braille_tabledesc(*args)
braille_tabledesc = _braille.braille_tabledesc

def braille_init():
  return _braille.braille_init()
braille_init = _braille.braille_init

def braille_close():
  return _braille.braille_close()
braille_close = _braille.braille_close

def braille_info(*args):
  return _braille.braille_info(*args)
braille_info = _braille.braille_info

def braille_size():
  return _braille.braille_size()
braille_size = _braille.braille_size

def braille_display(*args):
  return _braille.braille_display(*args)
braille_display = _braille.braille_display

def braille_write(*args):
  return _braille.braille_write(*args)
braille_write = _braille.braille_write

def braille_filter(*args):
  return _braille.braille_filter(*args)
braille_filter = _braille.braille_filter

def braille_statussize():
  return _braille.braille_statussize()
braille_statussize = _braille.braille_statussize

def braille_statusdisplay(*args):
  return _braille.braille_statusdisplay(*args)
braille_statusdisplay = _braille.braille_statusdisplay

def braille_statuswrite(*args):
  return _braille.braille_statuswrite(*args)
braille_statuswrite = _braille.braille_statuswrite

def braille_statusfilter(*args):
  return _braille.braille_statusfilter(*args)
braille_statusfilter = _braille.braille_statusfilter

def braille_statusrender():
  return _braille.braille_statusrender()
braille_statusrender = _braille.braille_statusrender

def braille_timeout(*args):
  return _braille.braille_timeout(*args)
braille_timeout = _braille.braille_timeout

def braille_read(*args):
  return _braille.braille_read(*args)
braille_read = _braille.braille_read

def braille_render():
  return _braille.braille_render()
braille_render = _braille.braille_render

def braille_usetable(*args):
  return _braille.braille_usetable(*args)
braille_usetable = _braille.braille_usetable

def braille_ascii2braille(*args):
  return _braille.braille_ascii2braille(*args)
braille_ascii2braille = _braille.braille_ascii2braille

def braille_braille2ascii(*args):
  return _braille.braille_braille2ascii(*args)
braille_braille2ascii = _braille.braille_braille2ascii

def braille_debug(*args):
  return _braille.braille_debug(*args)
braille_debug = _braille.braille_debug

def braille_geterror():
  return _braille.braille_geterror()
braille_geterror = _braille.braille_geterror
BRLK_UNKNOWN = _braille.BRLK_UNKNOWN
BRLK_NONE = _braille.BRLK_NONE
BRLK_BACKSPACE = _braille.BRLK_BACKSPACE
BRLK_TAB = _braille.BRLK_TAB
BRLK_CLEAR = _braille.BRLK_CLEAR
BRLK_RETURN = _braille.BRLK_RETURN
BRLK_PAUSE = _braille.BRLK_PAUSE
BRLK_ESCAPE = _braille.BRLK_ESCAPE
BRLK_SPACE = _braille.BRLK_SPACE
BRLK_EXCLAIM = _braille.BRLK_EXCLAIM
BRLK_QUOTEDBL = _braille.BRLK_QUOTEDBL
BRLK_HASH = _braille.BRLK_HASH
BRLK_DOLLAR = _braille.BRLK_DOLLAR
BRLK_AMPERSAND = _braille.BRLK_AMPERSAND
BRLK_QUOTE = _braille.BRLK_QUOTE
BRLK_LEFTPAREN = _braille.BRLK_LEFTPAREN
BRLK_RIGHTPAREN = _braille.BRLK_RIGHTPAREN
BRLK_ASTERISK = _braille.BRLK_ASTERISK
BRLK_PLUS = _braille.BRLK_PLUS
BRLK_COMMA = _braille.BRLK_COMMA
BRLK_MINUS = _braille.BRLK_MINUS
BRLK_PERIOD = _braille.BRLK_PERIOD
BRLK_SLASH = _braille.BRLK_SLASH
BRLK_0 = _braille.BRLK_0
BRLK_1 = _braille.BRLK_1
BRLK_2 = _braille.BRLK_2
BRLK_3 = _braille.BRLK_3
BRLK_4 = _braille.BRLK_4
BRLK_5 = _braille.BRLK_5
BRLK_6 = _braille.BRLK_6
BRLK_7 = _braille.BRLK_7
BRLK_8 = _braille.BRLK_8
BRLK_9 = _braille.BRLK_9
BRLK_COLON = _braille.BRLK_COLON
BRLK_SEMICOLON = _braille.BRLK_SEMICOLON
BRLK_LESS = _braille.BRLK_LESS
BRLK_EQUALS = _braille.BRLK_EQUALS
BRLK_GREATER = _braille.BRLK_GREATER
BRLK_QUESTION = _braille.BRLK_QUESTION
BRLK_AT = _braille.BRLK_AT
BRLK_LEFTBRACKET = _braille.BRLK_LEFTBRACKET
BRLK_BACKSLASH = _braille.BRLK_BACKSLASH
BRLK_RIGHTBRACKET = _braille.BRLK_RIGHTBRACKET
BRLK_CARET = _braille.BRLK_CARET
BRLK_UNDERSCORE = _braille.BRLK_UNDERSCORE
BRLK_BACKQUOTE = _braille.BRLK_BACKQUOTE
BRLK_a = _braille.BRLK_a
BRLK_b = _braille.BRLK_b
BRLK_c = _braille.BRLK_c
BRLK_d = _braille.BRLK_d
BRLK_e = _braille.BRLK_e
BRLK_f = _braille.BRLK_f
BRLK_g = _braille.BRLK_g
BRLK_h = _braille.BRLK_h
BRLK_i = _braille.BRLK_i
BRLK_j = _braille.BRLK_j
BRLK_k = _braille.BRLK_k
BRLK_l = _braille.BRLK_l
BRLK_m = _braille.BRLK_m
BRLK_n = _braille.BRLK_n
BRLK_o = _braille.BRLK_o
BRLK_p = _braille.BRLK_p
BRLK_q = _braille.BRLK_q
BRLK_r = _braille.BRLK_r
BRLK_s = _braille.BRLK_s
BRLK_t = _braille.BRLK_t
BRLK_u = _braille.BRLK_u
BRLK_v = _braille.BRLK_v
BRLK_w = _braille.BRLK_w
BRLK_x = _braille.BRLK_x
BRLK_y = _braille.BRLK_y
BRLK_z = _braille.BRLK_z
BRLK_DELETE = _braille.BRLK_DELETE
BRLK_WORLD_0 = _braille.BRLK_WORLD_0
BRLK_WORLD_1 = _braille.BRLK_WORLD_1
BRLK_WORLD_2 = _braille.BRLK_WORLD_2
BRLK_WORLD_3 = _braille.BRLK_WORLD_3
BRLK_WORLD_4 = _braille.BRLK_WORLD_4
BRLK_WORLD_5 = _braille.BRLK_WORLD_5
BRLK_WORLD_6 = _braille.BRLK_WORLD_6
BRLK_WORLD_7 = _braille.BRLK_WORLD_7
BRLK_WORLD_8 = _braille.BRLK_WORLD_8
BRLK_WORLD_9 = _braille.BRLK_WORLD_9
BRLK_WORLD_10 = _braille.BRLK_WORLD_10
BRLK_WORLD_11 = _braille.BRLK_WORLD_11
BRLK_WORLD_12 = _braille.BRLK_WORLD_12
BRLK_WORLD_13 = _braille.BRLK_WORLD_13
BRLK_WORLD_14 = _braille.BRLK_WORLD_14
BRLK_WORLD_15 = _braille.BRLK_WORLD_15
BRLK_WORLD_16 = _braille.BRLK_WORLD_16
BRLK_WORLD_17 = _braille.BRLK_WORLD_17
BRLK_WORLD_18 = _braille.BRLK_WORLD_18
BRLK_WORLD_19 = _braille.BRLK_WORLD_19
BRLK_WORLD_20 = _braille.BRLK_WORLD_20
BRLK_WORLD_21 = _braille.BRLK_WORLD_21
BRLK_WORLD_22 = _braille.BRLK_WORLD_22
BRLK_WORLD_23 = _braille.BRLK_WORLD_23
BRLK_WORLD_24 = _braille.BRLK_WORLD_24
BRLK_WORLD_25 = _braille.BRLK_WORLD_25
BRLK_WORLD_26 = _braille.BRLK_WORLD_26
BRLK_WORLD_27 = _braille.BRLK_WORLD_27
BRLK_WORLD_28 = _braille.BRLK_WORLD_28
BRLK_WORLD_29 = _braille.BRLK_WORLD_29
BRLK_WORLD_30 = _braille.BRLK_WORLD_30
BRLK_WORLD_31 = _braille.BRLK_WORLD_31
BRLK_WORLD_32 = _braille.BRLK_WORLD_32
BRLK_WORLD_33 = _braille.BRLK_WORLD_33
BRLK_WORLD_34 = _braille.BRLK_WORLD_34
BRLK_WORLD_35 = _braille.BRLK_WORLD_35
BRLK_WORLD_36 = _braille.BRLK_WORLD_36
BRLK_WORLD_37 = _braille.BRLK_WORLD_37
BRLK_WORLD_38 = _braille.BRLK_WORLD_38
BRLK_WORLD_39 = _braille.BRLK_WORLD_39
BRLK_WORLD_40 = _braille.BRLK_WORLD_40
BRLK_WORLD_41 = _braille.BRLK_WORLD_41
BRLK_WORLD_42 = _braille.BRLK_WORLD_42
BRLK_WORLD_43 = _braille.BRLK_WORLD_43
BRLK_WORLD_44 = _braille.BRLK_WORLD_44
BRLK_WORLD_45 = _braille.BRLK_WORLD_45
BRLK_WORLD_46 = _braille.BRLK_WORLD_46
BRLK_WORLD_47 = _braille.BRLK_WORLD_47
BRLK_WORLD_48 = _braille.BRLK_WORLD_48
BRLK_WORLD_49 = _braille.BRLK_WORLD_49
BRLK_WORLD_50 = _braille.BRLK_WORLD_50
BRLK_WORLD_51 = _braille.BRLK_WORLD_51
BRLK_WORLD_52 = _braille.BRLK_WORLD_52
BRLK_WORLD_53 = _braille.BRLK_WORLD_53
BRLK_WORLD_54 = _braille.BRLK_WORLD_54
BRLK_WORLD_55 = _braille.BRLK_WORLD_55
BRLK_WORLD_56 = _braille.BRLK_WORLD_56
BRLK_WORLD_57 = _braille.BRLK_WORLD_57
BRLK_WORLD_58 = _braille.BRLK_WORLD_58
BRLK_WORLD_59 = _braille.BRLK_WORLD_59
BRLK_WORLD_60 = _braille.BRLK_WORLD_60
BRLK_WORLD_61 = _braille.BRLK_WORLD_61
BRLK_WORLD_62 = _braille.BRLK_WORLD_62
BRLK_WORLD_63 = _braille.BRLK_WORLD_63
BRLK_WORLD_64 = _braille.BRLK_WORLD_64
BRLK_WORLD_65 = _braille.BRLK_WORLD_65
BRLK_WORLD_66 = _braille.BRLK_WORLD_66
BRLK_WORLD_67 = _braille.BRLK_WORLD_67
BRLK_WORLD_68 = _braille.BRLK_WORLD_68
BRLK_WORLD_69 = _braille.BRLK_WORLD_69
BRLK_WORLD_70 = _braille.BRLK_WORLD_70
BRLK_WORLD_71 = _braille.BRLK_WORLD_71
BRLK_WORLD_72 = _braille.BRLK_WORLD_72
BRLK_WORLD_73 = _braille.BRLK_WORLD_73
BRLK_WORLD_74 = _braille.BRLK_WORLD_74
BRLK_WORLD_75 = _braille.BRLK_WORLD_75
BRLK_WORLD_76 = _braille.BRLK_WORLD_76
BRLK_WORLD_77 = _braille.BRLK_WORLD_77
BRLK_WORLD_78 = _braille.BRLK_WORLD_78
BRLK_WORLD_79 = _braille.BRLK_WORLD_79
BRLK_WORLD_80 = _braille.BRLK_WORLD_80
BRLK_WORLD_81 = _braille.BRLK_WORLD_81
BRLK_WORLD_82 = _braille.BRLK_WORLD_82
BRLK_WORLD_83 = _braille.BRLK_WORLD_83
BRLK_WORLD_84 = _braille.BRLK_WORLD_84
BRLK_WORLD_85 = _braille.BRLK_WORLD_85
BRLK_WORLD_86 = _braille.BRLK_WORLD_86
BRLK_WORLD_87 = _braille.BRLK_WORLD_87
BRLK_WORLD_88 = _braille.BRLK_WORLD_88
BRLK_WORLD_89 = _braille.BRLK_WORLD_89
BRLK_WORLD_90 = _braille.BRLK_WORLD_90
BRLK_WORLD_91 = _braille.BRLK_WORLD_91
BRLK_WORLD_92 = _braille.BRLK_WORLD_92
BRLK_WORLD_93 = _braille.BRLK_WORLD_93
BRLK_WORLD_94 = _braille.BRLK_WORLD_94
BRLK_WORLD_95 = _braille.BRLK_WORLD_95
BRLK_KP0 = _braille.BRLK_KP0
BRLK_KP1 = _braille.BRLK_KP1
BRLK_KP2 = _braille.BRLK_KP2
BRLK_KP3 = _braille.BRLK_KP3
BRLK_KP4 = _braille.BRLK_KP4
BRLK_KP5 = _braille.BRLK_KP5
BRLK_KP6 = _braille.BRLK_KP6
BRLK_KP7 = _braille.BRLK_KP7
BRLK_KP8 = _braille.BRLK_KP8
BRLK_KP9 = _braille.BRLK_KP9
BRLK_KP_PERIOD = _braille.BRLK_KP_PERIOD
BRLK_KP_DIVIDE = _braille.BRLK_KP_DIVIDE
BRLK_KP_MULTIPLY = _braille.BRLK_KP_MULTIPLY
BRLK_KP_MINUS = _braille.BRLK_KP_MINUS
BRLK_KP_PLUS = _braille.BRLK_KP_PLUS
BRLK_KP_ENTER = _braille.BRLK_KP_ENTER
BRLK_KP_EQUALS = _braille.BRLK_KP_EQUALS
BRLK_UP = _braille.BRLK_UP
BRLK_DOWN = _braille.BRLK_DOWN
BRLK_RIGHT = _braille.BRLK_RIGHT
BRLK_LEFT = _braille.BRLK_LEFT
BRLK_INSERT = _braille.BRLK_INSERT
BRLK_HOME = _braille.BRLK_HOME
BRLK_END = _braille.BRLK_END
BRLK_PAGEUP = _braille.BRLK_PAGEUP
BRLK_PAGEDOWN = _braille.BRLK_PAGEDOWN
BRLK_F1 = _braille.BRLK_F1
BRLK_F2 = _braille.BRLK_F2
BRLK_F3 = _braille.BRLK_F3
BRLK_F4 = _braille.BRLK_F4
BRLK_F5 = _braille.BRLK_F5
BRLK_F6 = _braille.BRLK_F6
BRLK_F7 = _braille.BRLK_F7
BRLK_F8 = _braille.BRLK_F8
BRLK_F9 = _braille.BRLK_F9
BRLK_F10 = _braille.BRLK_F10
BRLK_F11 = _braille.BRLK_F11
BRLK_F12 = _braille.BRLK_F12
BRLK_F13 = _braille.BRLK_F13
BRLK_F14 = _braille.BRLK_F14
BRLK_F15 = _braille.BRLK_F15
BRLK_NUMLOCK = _braille.BRLK_NUMLOCK
BRLK_CAPSLOCK = _braille.BRLK_CAPSLOCK
BRLK_SCROLLOCK = _braille.BRLK_SCROLLOCK
BRLK_RSHIFT = _braille.BRLK_RSHIFT
BRLK_LSHIFT = _braille.BRLK_LSHIFT
BRLK_RCTRL = _braille.BRLK_RCTRL
BRLK_LCTRL = _braille.BRLK_LCTRL
BRLK_RALT = _braille.BRLK_RALT
BRLK_LALT = _braille.BRLK_LALT
BRLK_RMETA = _braille.BRLK_RMETA
BRLK_LMETA = _braille.BRLK_LMETA
BRLK_LSUPER = _braille.BRLK_LSUPER
BRLK_RSUPER = _braille.BRLK_RSUPER
BRLK_MODE = _braille.BRLK_MODE
BRLK_COMPOSE = _braille.BRLK_COMPOSE
BRLK_HELP = _braille.BRLK_HELP
BRLK_PRINT = _braille.BRLK_PRINT
BRLK_SYSREQ = _braille.BRLK_SYSREQ
BRLK_BREAK = _braille.BRLK_BREAK
BRLK_MENU = _braille.BRLK_MENU
BRLK_POWER = _braille.BRLK_POWER
BRLK_EURO = _braille.BRLK_EURO
BRLK_BACKWARD = _braille.BRLK_BACKWARD
BRLK_FORWARD = _braille.BRLK_FORWARD
BRLK_DOT7 = _braille.BRLK_DOT7
BRLK_DOT8 = _braille.BRLK_DOT8
BRLK_ACCORD_a = _braille.BRLK_ACCORD_a
BRLK_ACCORD_b = _braille.BRLK_ACCORD_b
BRLK_ACCORD_c = _braille.BRLK_ACCORD_c
BRLK_ACCORD_d = _braille.BRLK_ACCORD_d
BRLK_ACCORD_e = _braille.BRLK_ACCORD_e
BRLK_ACCORD_f = _braille.BRLK_ACCORD_f
BRLK_ACCORD_g = _braille.BRLK_ACCORD_g
BRLK_ACCORD_h = _braille.BRLK_ACCORD_h
BRLK_ACCORD_i = _braille.BRLK_ACCORD_i
BRLK_ACCORD_j = _braille.BRLK_ACCORD_j
BRLK_ACCORD_k = _braille.BRLK_ACCORD_k
BRLK_ACCORD_l = _braille.BRLK_ACCORD_l
BRLK_ACCORD_m = _braille.BRLK_ACCORD_m
BRLK_ACCORD_n = _braille.BRLK_ACCORD_n
BRLK_ACCORD_o = _braille.BRLK_ACCORD_o
BRLK_ACCORD_p = _braille.BRLK_ACCORD_p
BRLK_ACCORD_q = _braille.BRLK_ACCORD_q
BRLK_ACCORD_r = _braille.BRLK_ACCORD_r
BRLK_ACCORD_s = _braille.BRLK_ACCORD_s
BRLK_ACCORD_t = _braille.BRLK_ACCORD_t
BRLK_ACCORD_u = _braille.BRLK_ACCORD_u
BRLK_ACCORD_v = _braille.BRLK_ACCORD_v
BRLK_ACCORD_w = _braille.BRLK_ACCORD_w
BRLK_ACCORD_x = _braille.BRLK_ACCORD_x
BRLK_ACCORD_y = _braille.BRLK_ACCORD_y
BRLK_ACCORD_z = _braille.BRLK_ACCORD_z
BRLK_ABOVE = _braille.BRLK_ABOVE
BRLK_BELOW = _braille.BRLK_BELOW
BRLK_LAST = _braille.BRLK_LAST


